@@ -61,8 +61,8 @@ Challenge_Graph::Challenge_Graph( TQWidget* parent, const char* name, resource *
 	myStatusBar = new TQLabel( this, "Challenge_Graph_Status_Bar" );
 	myView = new Challenge_Graph_View( *graph, this, "Challenge_Graph_View", 0, myStatusBar );
 
-	TQT_BASE_OBJECT_NAME::connect(myView, TQT_SIGNAL(leftClick(int)), TQT_SLOT(selectMatch(int)));
-	TQT_BASE_OBJECT_NAME::connect(myView, TQT_SIGNAL(rightClick(Challenge_Game*, const TQPoint&)), TQT_SLOT(display_menuSeek(Challenge_Game*, const TQPoint&)));
+	TQObject::connect(myView, TQT_SIGNAL(leftClick(int)), TQT_SLOT(selectMatch(int)));
+	TQObject::connect(myView, TQT_SIGNAL(rightClick(Challenge_Game*, const TQPoint&)), TQT_SLOT(display_menuSeek(Challenge_Game*, const TQPoint&)));
 
 
 	/* Setup Style for myStatusBar */
