@@ -40,7 +40,7 @@ typedef KnightsMap<int, io_base*> IOMap;
 
 class core : public TQWidget
 {
-   Q_OBJECT
+   TQ_OBJECT
   
   public:
                                 core(TQWidget *parent=0, const char *name=0, resource *Rsrc=0);
