@@ -18,7 +18,7 @@
 /* KDE */
 #include <ksock.h>
 #include <kprocess.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 
 /* TQt */
 #include <tqobject.h>
@@ -144,7 +144,7 @@ void io_internet::connectToServer()
 
   if(!myServer->Timeseal.isEmpty())
   {
-    myTimeseal = new KProcess();
+    myTimeseal = new TDEProcess();
     (*myTimeseal) << myServer->Timeseal << myServer->URL << TQString().setNum( myServer->Port )
                   << TQString( "-p" ) << TQString().setNum(myServer->Port + 1);
     if(!myTimeseal->start())
@@ -155,14 +155,14 @@ void io_internet::connectToServer()
       TQApplication::postEvent( tqApp->mainWidget(), new TQCustomEvent( EVENT_Del_IO_Net ) );
       return;
     }
-    socket = new KSocket("127.0.0.1", myServer->Port + 1, 30);
+    socket = new TDESocket("127.0.0.1", myServer->Port + 1, 30);
     if(socket->socket() == -1)
     {
       /* try again on a different port, somehow the port hasn't been freed yet */
       delete socket;
       myTimeseal->kill();
 
-      myTimeseal = new KProcess();
+      myTimeseal = new TDEProcess();
       (*myTimeseal) << myServer->Timeseal << myServer->URL << TQString().setNum( myServer->Port )
                     << TQString( "-p" ) << TQString().setNum(myServer->Port + 2);
       if(!myTimeseal->start())                                              
@@ -173,7 +173,7 @@ void io_internet::connectToServer()
         TQApplication::postEvent( tqApp->mainWidget(), new TQCustomEvent( EVENT_Del_IO_Net ) );
         return;
       }
-      socket = new KSocket("127.0.0.1", myServer->Port + 2, 30);
+      socket = new TDESocket("127.0.0.1", myServer->Port + 2, 30);
       if(socket->socket() == -1)
       {
         /* if we can't do it the second time, give up */
@@ -187,7 +187,7 @@ void io_internet::connectToServer()
   }
   else
   {
-    socket = new KSocket(myServer->URL, myServer->Port, 30);
+    socket = new TDESocket(myServer->URL.utf8(), myServer->Port, 30);
     if(socket->socket() == -1)
     {
       /* Couldn't connect to server. Notify User and die gracefully */
@@ -201,7 +201,7 @@ void io_internet::connectToServer()
   socket->enableWrite(true);
 
   /* connect a signal to readReady */
-  connect(socket, TQT_SIGNAL(readEvent(KSocket *)), this, TQT_SLOT(readCommand(KSocket *)));
+  connect(socket, TQT_SIGNAL(readEvent(TDESocket *)), this, TQT_SLOT(readCommand(TDESocket *)));
 
   /* setup the seekTimer and turn it off by default */
   seekTimer = new TQTimer(this);
@@ -221,7 +221,7 @@ void io_internet::connectToServer()
 			and close these tabs at will, or have multiple open at once. ALL communication to our tabs
 			needs to be done with SIGNALS & SLOTS to facilitate this.
 	*/
-	consoleTab = new Console( 0, myServer->Name, myResource );
+	consoleTab = new Console( 0, myServer->Name.utf8(), myResource );
 	myTabList[consoleTab] = consoleTab;
 	myResource->tabManager->addTab( myTabList[consoleTab], i18n( "%1 Console" ).arg( myServer->Name ) );
   connect( myTabList[consoleTab], TQT_SIGNAL( sendCMD( const Command& ) ), this, TQT_SLOT( recvCMD( const Command& ) ) );
@@ -383,7 +383,7 @@ void io_internet::send(const TQString& msg)
 //	io_internet::readCommand
 //
 ///////////////////////////////////////
-void io_internet::readCommand(KSocket* socket)
+void io_internet::readCommand(TDESocket* socket)
 {
   char buffer[READ_BUFFER_SIZE];
   TQString tmp;
@@ -847,9 +847,9 @@ void io_internet::parseStyle12(TQString line, const unsigned int Mode)
       }
 
       /* Verbose Coordinate Notation of previous move ( USE AS CAN ) */
-      strcpy(move.CAN, fields[27].right(fields[27].length() - 2).replace(TQRegExp("-"), ""));
+      strcpy(move.CAN, fields[27].right(fields[27].length() - 2).replace(TQRegExp("-"), "").utf8());
       /* SAN  */
-      strcpy(move.SAN, fields[29].replace(TQRegExp("\\+"), "").replace(TQRegExp("#"), ""));
+      strcpy(move.SAN, fields[29].replace(TQRegExp("\\+"), "").replace(TQRegExp("#"), "").utf8());
 
       /* fill the line for the command */
       position_line += fields[1];  /* Internal Rank #7 */
@@ -1024,7 +1024,7 @@ void io_internet::parseMoveList(TQString line)
   move.ICS_MoveCounter = move_counter;
   move.ICS_Mode = ICS_Movelist;
   move.ICS_OnMove = WHITE;
-  strcpy(move.SAN, two_plys[1]);
+  strcpy(move.SAN, two_plys[1].utf8());
   command.setCommand((int&)CMD_Move);
   command.setID(fics_to_knights[ficsMoveListNumber]);
   command.setMove(move);
@@ -1037,7 +1037,7 @@ void io_internet::parseMoveList(TQString line)
     move.ICS_MoveCounter = move_counter;
     move.ICS_Mode = ICS_Movelist;
     move.ICS_OnMove = BLACK;
-    strcpy(move.SAN, two_plys[3]);
+    strcpy(move.SAN, two_plys[3].utf8());
     command.setCommand((int&)CMD_Move);
     command.setID(fics_to_knights[ficsMoveListNumber]);
     command.setMove(move);
