@@ -47,7 +47,7 @@ Knights::Knights(TDECmdLineArgs *Args, TQWidget *parent, const char *name) : TDE
 	Minimized = FALSE;
 	args = Args;
 	SplashScreen = NULL;
-	setFocusPolicy( TQ_ClickFocus );
+	setFocusPolicy( TQWidget::ClickFocus );
 }
 
 Knights::~Knights()
