@@ -305,7 +305,7 @@ void pgn::init( void )
 ///////////////////////////////////////
 int pgn::scan( void )
 {
-	register int Section(0);
+	int Section(0);
 	TQChar c;
 
 	clearTags();
