@@ -30,7 +30,7 @@ class resource;
 
 class TabBox : public TQVBox
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 								TabBox( resource *rsrc=0 );
