@@ -138,10 +138,10 @@ void TabPage::setCaption( const TQString &caption )
 TabBox* TabPage::parentTabBox( void )
 {
 	TQWidget *myParent = this->parentWidget();
-	if( TQString( myParent->className() ) == TQWIDGETSTACK_OBJECT_NAME_STRING )
+	if( TQString( myParent->className() ) == "TQWidgetStack" )
 	{
 		myParent = myParent->parentWidget();
-		if( TQString( myParent->className() ) == TQTABWIDGET_OBJECT_NAME_STRING )
+		if( TQString( myParent->className() ) == "TQTabWidget" )
 		{
 			myParent = myParent->parentWidget();
 			if( TQString( myParent->className() ) == "TabBox" )
