@@ -175,7 +175,7 @@ void thinbuttons::buttonClicked( void )
 	int Clicked;
 	unsigned int tmp;
 
-	incomming = TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()));
+	incomming = sender();
 	for( tmp = 0; tmp < buttons.count(); tmp++ )
 		if( buttons.at( tmp )->button == ( const TQButton* )incomming )
 		{
